# Försäkringskassans Leverera förmånsinformation (LEFI)

E-tjänsten _Leverera förmånsinformation_ (LEFI) låter anslutna [aktörer](AKTOR.md) begära ut information om Försäkringskassans och Pensionsmyndighetens kunders ärenden och uppgifter. Det här arkivet samlar den information som behövs för att fysiskt ansluta till och nyttja Försäkringskassans produktionsmiljö för LEFI, vilken inkluderar API-specifikationer, URL:er och beskrivningar.

Mer information om LEFI hittar du på https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/lefi-online.

## Innehållsförteckning
1. Tjänstebeskrivning
    - 1.1 Förmånsinformation
2. Miljöbeskrivning
    - 2.1 Anslutning

## 1. Tjänstebeskrivning

LEFI låter en ansluten [aktör](AKTOR.md), såsom ett försäkringsbolag, en kommun, eller en avdelning på en kommun, att hämta information om ärenden eller andra uppgifter om Försäkringskassans kunder. 
Olika aktörer har olika rättsliga förutsättningar för att ta begära och ta emot denna information. Av den anledningen låter e-tjänsten också respektive aktör att hämta en sammanställning av vilka klasser och typer av förmånsinformation denne har rätt till.

[LEFI]: https://www.forsakringskassan.se/myndigheter-och-samarbetspartner/e-tjanster-for-myndigheter-och-samarbetspartner/lefi-online

Förmånsinformation och tillgängliga informationstyper hämtas via det HTTP-baserade gränssnitt som beskrivs i det följande underavsnittet. Tjänstens _OpenAPI-specifikation_, vilken är en programmatisk beskrivning av gränssnittets operationer och datatyper, finns att hitta i mappen `openapi/`.

### 1.1 Förmånsinformation

Gränssnittet tillhandahåller två operationer, en för att _hämta tillgängliga informationstyper_ och en för att _hämta förmånsinformation_. Den första operationen används för att ta reda på vilka [klasser och typer av information](INFORMATIONSTYP.md) en aktuell aktör _kan_ begära ut. En delmängd av dessa klasser och typer kan sedan tillhandahållas den andra operationen för att hämta den förmånsinformation som önskas och finns att tillgå.

Specificeras en informationstyp i en hämtningsfråga som inte en aktör har rätt till underkänns frågan och inget svar skickas tillbaka. Notera att i tidigare versioner av LEFI Online ignorerades istället typer av information där rättigheter saknades. Möjligheten att begära ut listor med tillgängliga typer av information är också nytt för LEFI version 9.

## 2. Miljöbeskrivning

LEFI:s produktionsmiljö utgörs av två tjänster, en synkron och en asynkron.

### 2.1 Anslutning

För att ansluta till LEFI:s produktionsmiljö krävs att aktören genomgår en anslutningsprocess. Den finns beskriven på [websidan för LEFI Online][LEFI].

Nyttjande av LEFI:s produktionsmiljö kräver även att en HTTPS-klient används som är konfigurerad att använda ett klient-certifikat som godkänns av Försäkringskassan. Instruktioner om hur ett godkänt certifikat erhålls, samt vilka certifikat som måste betraktas som betrodda, finns på [websidan för LEFI Online][LEFI].

#### 2.1.1 Gränssnittens URL:er

När ett godkänt certifikat är på plats (och HTTPS-klienten i fråga är konfigurerad att använda det med mTLS) ska följande bas-URL:er användas för att skicka meddelanden till de båda gränssnitten.

| Gränssnitt    | Bas-URL                                                                          |
|:--------------|:---------------------------------------------------------------------------------|
| LEFI Online | https://fmansinfo.forsakringskassan.se:7020/rest/FK.EXI.LevereraFormansinformation.V9/ |

En bas-URL är alltså en URL som saknar sökvägen från en specifik API-operation. För att, exempelvis, skicka ett meddelande till aviseringsgränssnittets operation `hamtaFormansinformation`, vilken har sökvägen `/lefi-extern-formansinformation/v9/aktorer/{aktorsId}/formansinformation/fraga`, måste följande sökväg användas:

```
https://fmansinfo.forsakringskassan.se:7020/rest/FK.EXI.LevereraFormansinformation.V9/lefi-extern-formansinformation/v9/aktorer/{aktorsId}/formansinformation/fraga
```

URL-schemat och -auktoriteten som används av samtliga utav testmiljöns operationer är alltså `https://fmansinfo.forsakringskassan.se:7020/rest`. Denna typ av URL referas också till som _inlämningsadress_ i övrig dokumentation för LEFI Online.

#### 2.1.2 Header "Content-Type"

Kontrollera att headern ’Content-Type: application/json’ är satt i anropet till tjänsten, annars går det fel redan i integrationen.
